[Compare the full difference.](https://github.com/callowayproject/bump-my-version/compare/1.1.1...1.1.2)

### Fixes

- Fix ident level when bump() or parse() throws exceptions. [dd6a841](https://github.com/callowayproject/bump-my-version/commit/dd6a841e72128098be20409b1961256e07eb8b09)
    
### Other

- [pre-commit.ci] pre-commit autoupdate. [10b76f6](https://github.com/callowayproject/bump-my-version/commit/10b76f619c57321ad136ac379d8f9a2a1d2a5304)
    
  **updates:** - [github.com/astral-sh/ruff-pre-commit: v0.11.0 → v0.11.4](https://github.com/astral-sh/ruff-pre-commit/compare/v0.11.0...v0.11.4)

- Testing write access. [31bab59](https://github.com/callowayproject/bump-my-version/commit/31bab59b8cceaad6e35351553c599fb1e4e45dd2)
    
